@@ -1,6 +1,6 @@
 #' Calculate graph small-worldness
 #'
-#' \code{small.world} calculates the normalizaed characteristic path length and
+#' \code{small.world} calculates the normalized characteristic path length and
 #' clustering coefficient based on observed and random graphs, used to calculate
 #' the small-world coefficient \eqn{\sigma}.
 #'
@@ -21,25 +21,30 @@
 #' @author Christopher G. Watson, \email{cgwatson@@bu.edu}
 #' @references Watts, D.J. and Strogatz S.H. (1998) Collective dynamics of
 #'   "small-world" networks. \emph{Nature}, \bold{393}, 440--442.
-#'   \url{https://dx.doi.org/10.1515/9781400841356.301}
+#'   \url{https://dx.doi.org/10.1038/30918}
 
 small.world <- function(g.list, rand) {
+  level <- NULL
+  sID <- getOption('bg.subject_id')
+  gID <- getOption('bg.group')
+
   if (is_igraph(g.list) || is.brainGraph(g.list)) {
     g.list <- list(g.list)
-  } else if (inherits(g.list, 'brainGraphList')) {
+  } else if (is.brainGraphList(g.list)) {
+    level <- g.list$level
     g.list <- g.list$graphs
     rand <- rand$graphs
   } else if (!is.list(g.list)) {
     stop('Input should be a list, igraph, brainGraph, or brainGraphList object.')
   }
 
-  Lp <- vapply(g.list, graph_attr, numeric(1), 'Lp')
-  Cp <- vapply(g.list, graph_attr, numeric(1), 'Cp')
-  densities <- vapply(g.list, graph_attr, numeric(1), 'density')
+  Lp <- vapply(g.list, graph_attr, numeric(1L), 'Lp')
+  Cp <- vapply(g.list, graph_attr, numeric(1L), 'Cp')
+  densities <- vapply(g.list, graph_attr, numeric(1L), 'density')
 
   N <- lengths(rand)
-  Lp.rand <- colMeans(vapply(rand, vapply, numeric(N[1]), graph_attr, numeric(1), 'Lp'))
-  Cp.rand <- colMeans(vapply(rand, vapply, numeric(N[1]), graph_attr, numeric(1), 'Cp'))
+  Lp.rand <- colMeans(vapply(rand, vapply, numeric(N[1L]), graph_attr, numeric(1L), 'Lp'))
+  Cp.rand <- colMeans(vapply(rand, vapply, numeric(N[1L]), graph_attr, numeric(1L), 'Cp'))
 
   Cp.norm <- Cp / Cp.rand
   Lp.norm <- Lp / Lp.rand
@@ -47,15 +52,15 @@ small.world <- function(g.list, rand) {
   DT <- data.table(density=densities, N, Lp, Cp, Lp.rand, Cp.rand,
                    Lp.norm, Cp.norm, sigma)
   if (!is.null(names(g.list))) {
-    sID <- getOption('bg.subject_id')
     DT[, eval(sID) := names(g.list)]
   }
   attrs <- c('Group', 'threshold')
   for (x in attrs) {
-    if (x %in% graph_attr_names(g.list[[1]])) {
+    if (x %in% graph_attr_names(g.list[[1L]])) {
       DT[, eval(x) := sapply(g.list, graph_attr, x)]
     }
   }
-  if ('Group' %in% names(DT)) setnames(DT, 'Group', getOption('bg.group'))
+  if (hasName(DT, 'Group')) setnames(DT, 'Group', gID)
+  if (level == 'group' && DT[, all(get(sID) == get(gID))]) DT[, eval(sID) := NULL]
   return(DT)
 }
