@@ -40,8 +40,8 @@ vulnerability <- function(g, use.parallel=TRUE, weighted=FALSE) {
   calc <- g.attr %in% graph_attr_names(g)
   E.global <- if (calc) efficiency(g, 'global', weights) else graph_attr(g, g.attr)
 
-  vuln <- rep(0, dim(A)[1L])
-  verts <- which(rowSums((A > 0) + 0) != 0)
+  vuln <- rep.int(0, dim(A)[1L])
+  verts <- which(rowSums((A > 0) + 0L) != 0L)
   `%d%` <- `%do%`
   if (isTRUE(use.parallel)) {
     if (!getDoParRegistered()) {
@@ -51,7 +51,7 @@ vulnerability <- function(g, use.parallel=TRUE, weighted=FALSE) {
     `%d%` <- `%dopar%`
   }
   vuln[verts] <- foreach(i=verts, .combine='c') %d% {
-    g.tmp <- graph_from_adjacency_matrix(A[-i, -i], mode='undirected', weighted=weighted)
+    g.tmp <- graph_from_adjacency_matrix(A[-i, -i, drop=FALSE], mode='undirected', weighted=weighted)
     E.global.tmp <- efficiency(g.tmp, 'global', weights)
     1 - (E.global.tmp / E.global)
   }
